Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4258)

Unified Diff: chrome/browser/chromeos/arc/optin/arc_terms_of_service_oobe_negotiator.h

Issue 2700303002: cros: Unify oobe View/Actor naming to just View. (Closed)
Patch Set: Rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/arc/optin/arc_terms_of_service_oobe_negotiator.h
diff --git a/chrome/browser/chromeos/arc/optin/arc_terms_of_service_oobe_negotiator.h b/chrome/browser/chromeos/arc/optin/arc_terms_of_service_oobe_negotiator.h
index df6f470d5f916353bd38b01316d60ebb61aaa750..59af5dc657a241f46570a366c70ea94f3c7f0caa 100644
--- a/chrome/browser/chromeos/arc/optin/arc_terms_of_service_oobe_negotiator.h
+++ b/chrome/browser/chromeos/arc/optin/arc_terms_of_service_oobe_negotiator.h
@@ -7,10 +7,10 @@
#include "base/macros.h"
#include "chrome/browser/chromeos/arc/optin/arc_terms_of_service_negotiator.h"
-#include "chrome/browser/chromeos/login/screens/arc_terms_of_service_screen_actor_observer.h"
+#include "chrome/browser/chromeos/login/screens/arc_terms_of_service_screen_view_observer.h"
namespace chromeos {
-class ArcTermsOfServiceScreenActor;
+class ArcTermsOfServiceScreenView;
}
namespace arc {
@@ -18,39 +18,39 @@ namespace arc {
// Handles the Terms-of-service agreement user action via OOBE OptIn UI.
class ArcTermsOfServiceOobeNegotiator
: public ArcTermsOfServiceNegotiator,
- public chromeos::ArcTermsOfServiceScreenActorObserver {
+ public chromeos::ArcTermsOfServiceScreenViewObserver {
public:
ArcTermsOfServiceOobeNegotiator();
~ArcTermsOfServiceOobeNegotiator() override;
// Injects ARC OOBE screen handler in unit tests, where OOBE UI is not
// available.
- static void SetArcTermsOfServiceScreenActorForTesting(
- chromeos::ArcTermsOfServiceScreenActor* actor);
+ static void SetArcTermsOfServiceScreenViewForTesting(
+ chromeos::ArcTermsOfServiceScreenView* view);
private:
// Helper to handle callbacks from
// chromeos::ArcTermsOfServiceScreenActorObserver. It removes observer from
// |screen_actor_|, resets it, and then dispatches |accepted|. It is expected
// that this method is called exactly once for each instance of
// ArcTermsOfServiceOobeNegotiator.
void HandleTermsAccepted(bool accepted);
- // chromeos::ArcTermsOfServiceScreenActorObserver:
+ // chromeos::ArcTermsOfServiceScreenViewObserver:
void OnSkip() override;
void OnAccept() override;
- void OnActorDestroyed(chromeos::ArcTermsOfServiceScreenActor* actor) override;
+ void OnViewDestroyed(chromeos::ArcTermsOfServiceScreenView* view) override;
// ArcTermsOfServiceNegotiator:
void StartNegotiationImpl() override;
// Unowned pointer. If a user signs out while ARC OOBE opt-in is active,
// LoginDisplayHost is detached first then OnActorDestroyed is called.
// It means, in OnSkip() and OnAccept(), the Actor needs to be obtained via
// LoginDisplayHost, but in OnActorDestroyed(), the argument needs to be used.
// In order to use the same way to access the Actor, remember the pointer in
// StartNegotiationImpl(), and reset in HandleTermsAccepted().
- chromeos::ArcTermsOfServiceScreenActor* screen_actor_ = nullptr;
+ chromeos::ArcTermsOfServiceScreenView* screen_view_ = nullptr;
DISALLOW_COPY_AND_ASSIGN(ArcTermsOfServiceOobeNegotiator);
};
@@ -18,39 +18,39 @@ namespace arc {
private:
// Helper to handle callbacks from
- // chromeos::ArcTermsOfServiceScreenActorObserver. It removes observer from
- // |screen_actor_|, resets it, and then dispatches |accepted|. It is expected
+ // chromeos::ArcTermsOfServiceScreenViewObserver. It removes observer from
+ // |screen_view_|, resets it, and then dispatches |accepted|. It is expected
// that this method is called exactly once for each instance of
// ArcTermsOfServiceOobeNegotiator.
@@ -18,39 +18,39 @@ namespace arc {
void StartNegotiationImpl() override;
// Unowned pointer. If a user signs out while ARC OOBE opt-in is active,
- // LoginDisplayHost is detached first then OnActorDestroyed is called.
- // It means, in OnSkip() and OnAccept(), the Actor needs to be obtained via
- // LoginDisplayHost, but in OnActorDestroyed(), the argument needs to be used.
- // In order to use the same way to access the Actor, remember the pointer in
+ // LoginDisplayHost is detached first then OnViewDestroyed is called.
+ // It means, in OnSkip() and OnAccept(), the View needs to be obtained via
+ // LoginDisplayHost, but in OnViewDestroyed(), the argument needs to be used.
+ // In order to use the same way to access the View, remember the pointer in
// StartNegotiationImpl(), and reset in HandleTermsAccepted().

Powered by Google App Engine
This is Rietveld 408576698